Struct google_androidmanagement1::ApiLevelCondition [−][src]
A compliance rule condition which is satisfied if the Android Framework API level on the device does not meet a minimum requirement. There can only be one rule with this type of condition per policy.
This type is not used in any activity, and only used as part of another schema.
Fields
min_api_level: Option<i32>
The minimum desired Android Framework API level. If the device does not meet the minimum requirement, this condition is satisfied. Must be greater than zero.