Struct google_androidmanagement1::Command
source · pub struct Command {
pub duration: Option<String>,
pub reset_password_flags: Option<Vec<String>>,
pub new_password: Option<String>,
pub type_: Option<String>,
pub create_time: Option<String>,
}Expand description
A command.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- devices issue command enterprises (request)
Fields
duration: Option<String>The duration for which the command is valid. The command will expire if not executed by the device during this time. The default duration if unspecified is ten minutes. There is no maximum duration.
reset_password_flags: Option<Vec<String>>For commands of type RESET_PASSWORD, optionally specifies flags.
new_password: Option<String>For commands of type RESET_PASSWORD, optionally specifies the new password.
type_: Option<String>The type of the command.
create_time: Option<String>The timestamp at which the command was created. The timestamp is automatically generated by the server.