Struct google_androidmanagement1::Device [−][src]
pub struct Device {
pub hardware_info: Option<HardwareInfo>,
pub applied_policy_name: Option<String>,
pub network_info: Option<NetworkInfo>,
pub management_mode: Option<String>,
pub memory_events: Option<Vec<MemoryEvent>>,
pub power_management_events: Option<Vec<PowerManagementEvent>>,
pub enrollment_token_name: Option<String>,
pub displays: Option<Vec<Display>>,
pub non_compliance_details: Option<Vec<NonComplianceDetail>>,
pub hardware_status_samples: Option<Vec<HardwareStatus>>,
pub api_level: Option<i32>,
pub last_policy_sync_time: Option<String>,
pub applied_policy_version: Option<String>,
pub user_name: Option<String>,
pub policy_name: Option<String>,
pub disabled_reason: Option<UserFacingMessage>,
pub enrollment_token_data: Option<String>,
pub name: Option<String>,
pub previous_device_names: Option<Vec<String>>,
pub user: Option<User>,
pub software_info: Option<SoftwareInfo>,
pub applied_state: Option<String>,
pub policy_compliant: Option<bool>,
pub enrollment_time: Option<String>,
pub state: Option<String>,
pub memory_info: Option<MemoryInfo>,
pub last_policy_compliance_report_time: Option<String>,
pub device_settings: Option<DeviceSettings>,
pub application_reports: Option<Vec<ApplicationReport>>,
pub last_status_report_time: Option<String>,
}A device owned by an enterprise. Unless otherwise noted, all fields are read-only and can't be modified by enterprises.devices.patch.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- devices patch enterprises (request|response)
- devices get enterprises (response)
Fields
hardware_info: Option<HardwareInfo>
Detailed information about the device hardware.
applied_policy_name: Option<String>
The name of the policy currently applied to the device.
network_info: Option<NetworkInfo>
Device network information. This information is only available if networkInfoEnabled is true in the device's policy.
management_mode: Option<String>
The type of management mode Android Device Policy takes on the device. This influences which policy settings are supported.
memory_events: Option<Vec<MemoryEvent>>
Events related to memory and storage measurements in chronological order. This information is only available if memoryInfoEnabled is true in the device's policy.
power_management_events: Option<Vec<PowerManagementEvent>>
Power management events on the device in chronological order. This information is only available if powerManagementEventsEnabled is true in the device's policy.
enrollment_token_name: Option<String>
If the device was enrolled with an enrollment token, this field contains the name of the token.
displays: Option<Vec<Display>>
Detailed information about displays on the device. This information is only available if displayInfoEnabled is true in the device's policy.
non_compliance_details: Option<Vec<NonComplianceDetail>>
Details about policy settings that the device is not compliant with.
hardware_status_samples: Option<Vec<HardwareStatus>>
Hardware status samples in chronological order. This information is only available if hardwareStatusEnabled is true in the device's policy.
api_level: Option<i32>
The API level of the Android platform version running on the device.
last_policy_sync_time: Option<String>
The last time the device fetched its policy.
applied_policy_version: Option<String>
The version of the policy currently applied to the device.
user_name: Option<String>
The resource name of the user that owns this device in the form enterprises/{enterpriseId}/users/{userId}.
policy_name: Option<String>
The name of the policy applied to the device, in the form enterprises/{enterpriseId}/policies/{policyId}. If not specified, the policy_name for the device's user is applied. This field can be modified by a patch request. You can specify only the policyId when calling enterprises.devices.patch, as long as the policyId doesn’t contain any slashes. The rest of the policy name is inferred.
disabled_reason: Option<UserFacingMessage>
If the device state is DISABLED, an optional message that is displayed on the device indicating the reason the device is disabled. This field can be modified by a patch request.
enrollment_token_data: Option<String>
If the device was enrolled with an enrollment token with additional data provided, this field contains that data.
name: Option<String>
The name of the device in the form enterprises/{enterpriseId}/devices/{deviceId}.
previous_device_names: Option<Vec<String>>
If the same physical device has been enrolled multiple times, this field contains its previous device names. The serial number is used as the unique identifier to determine if the same physical device has enrolled previously. The names are in chronological order.
user: Option<User>
The user who owns the device.
software_info: Option<SoftwareInfo>
Detailed information about the device software. This information is only available if softwareInfoEnabled is true in the device's policy.
applied_state: Option<String>
The state currently applied to the device.
policy_compliant: Option<bool>
Whether the device is compliant with its policy.
enrollment_time: Option<String>
The time of device enrollment.
state: Option<String>
The state to be applied to the device. This field can be modified by a patch request. Note that when calling enterprises.devices.patch, ACTIVE and DISABLED are the only allowable values. To enter the device into a DELETED state, call enterprises.devices.delete.
memory_info: Option<MemoryInfo>
Memory information. This information is only available if memoryInfoEnabled is true in the device's policy.
last_policy_compliance_report_time: Option<String>
Deprecated.
device_settings: Option<DeviceSettings>
Device settings information. This information is only available if deviceSettingsEnabled is true in the device's policy.
application_reports: Option<Vec<ApplicationReport>>
Reports for apps installed on the device. This information is only available when application_reports_enabled is true in the device's policy.
last_status_report_time: Option<String>
The last time the device sent a status report.