Struct google_androidmanagement1::Display [−][src]
pub struct Display {
pub refresh_rate: Option<i32>,
pub width: Option<i32>,
pub state: Option<String>,
pub name: Option<String>,
pub density: Option<i32>,
pub display_id: Option<i32>,
pub height: Option<i32>,
}Device display information.
This type is not used in any activity, and only used as part of another schema.
Fields
refresh_rate: Option<i32>
Refresh rate of the display in frames per second.
width: Option<i32>
Display width in pixels.
state: Option<String>
State of the display.
name: Option<String>
Name of the display.
density: Option<i32>
Display density expressed as dots-per-inch.
display_id: Option<i32>
Unique display id.
height: Option<i32>
Display height in pixels.