[−][src]Struct google_androidmanagement1::HardwareStatus
Hardware status. Temperatures may be compared to the temperature thresholds available in hardwareInfo to determine hardware health.
This type is not used in any activity, and only used as part of another schema.
Fields
battery_temperatures: Option<Vec<f32>>Current battery temperatures in Celsius for each battery on the device.
skin_temperatures: Option<Vec<f32>>Current device skin temperatures in Celsius.
gpu_temperatures: Option<Vec<f32>>Current GPU temperatures in Celsius for each GPU on the device.
fan_speeds: Option<Vec<f32>>Fan speeds in RPM for each fan on the device. Empty array means that there are no fans or fan speed is not supported on the system.
cpu_temperatures: Option<Vec<f32>>Current CPU temperatures in Celsius for each CPU on the device.
create_time: Option<String>The time the measurements were taken.
cpu_usages: Option<Vec<f32>>CPU usages in percentage for each core available on the device. Usage is 0 for each unplugged core. Empty array implies that CPU usage is not supported in the system.