Struct google_androidmanagement1::ProxyInfo[][src]

pub struct ProxyInfo {
    pub pac_uri: Option<String>,
    pub excluded_hosts: Option<Vec<String>>,
    pub host: Option<String>,
    pub port: Option<i32>,
}

Configuration info for an HTTP proxy. For a direct proxy, set the host, port, and excluded_hosts fields. For a PAC script proxy, set the pac_uri field.

This type is not used in any activity, and only used as part of another schema.

Fields

The URI of the PAC script used to configure the proxy.

For a direct proxy, the hosts for which the proxy is bypassed. The host names may contain wildcards such as *.example.com.

The host of the direct proxy.

The port of the direct proxy.