Struct google_androidmanagement1::SystemUpdate [−][src]
pub struct SystemUpdate {
pub end_minutes: Option<i32>,
pub start_minutes: Option<i32>,
pub type_: Option<String>,
}Configuration for managing system updates
This type is not used in any activity, and only used as part of another schema.
Fields
end_minutes: Option<i32>
If the type is WINDOWED, the end of the maintenance window, measured as the number of minutes after midnight in device local time. This value must be between 0 and 1439, inclusive. If this value is less than start_minutes, then the maintenance window spans midnight. If the maintenance window specified is smaller than 30 minutes, the actual window is extended to 30 minutes beyond the start time.
start_minutes: Option<i32>
If the type is WINDOWED, the start of the maintenance window, measured as the number of minutes after midnight in device local time. This value must be between 0 and 1439, inclusive.
type_: Option<String>
The type of system update to configure.