Struct google_androidmanagement1::WebToken [−][src]
pub struct WebToken {
pub parent_frame_url: Option<String>,
pub name: Option<String>,
pub value: Option<String>,
pub permissions: Option<Vec<String>>,
}A web token used to access an embeddable managed Google Play web UI.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- web tokens create enterprises (request|response)
Fields
parent_frame_url: Option<String>
The URL of the parent frame hosting the iframe with the embedded UI. To prevent XSS, the iframe may not be hosted at other URLs. The URL must use the https scheme.
name: Option<String>
The name of the web token, which is generated by the server during creation, in the form enterprises/{enterpriseId}/webTokens/{webTokenId}.
value: Option<String>
The token value which is used in the hosting page to generate the iframe with the embedded UI. This is a read-only field generated by the server.
permissions: Option<Vec<String>>
Permissions the admin may exercise in the embedded UI. The admin must have all of these permissions in order to view the UI.