Struct google_androidmanagement1::ApplicationPolicy [−][src]
pub struct ApplicationPolicy {
pub install_type: Option<String>,
pub managed_configuration: Option<HashMap<String, String>>,
pub lock_task_allowed: Option<bool>,
pub package_name: Option<String>,
pub permission_grants: Option<Vec<PermissionGrant>>,
pub default_permission_policy: Option<String>,
}Policy for an individual app.
This type is not used in any activity, and only used as part of another schema.
Fields
install_type: Option<String>
The type of installation to perform.
managed_configuration: Option<HashMap<String, String>>
Managed configuration applied to the app. The format for the configuration is dictated by the ManagedProperty values supported by the app. Each field name in the managed configuration must match the key field of the ManagedProperty. The field value must be compatible with the type of the ManagedProperty:
| type | JSON value |
| BOOL | true or false |
| STRING | string |
| INTEGER | number |
| CHOICE | string |
| MULTISELECT | array of strings |
| HIDDEN | string |
| BUNDLE_ARRAY | array of objects |
lock_task_allowed: Option<bool>
Whether the application is allowed to lock itself in full-screen mode.
package_name: Option<String>
The package name of the app, e.g. com.google.android.youtube for the YouTube app.
permission_grants: Option<Vec<PermissionGrant>>
Explicit permission grants or denials for the app. These values override the default_permission_policy.
default_permission_policy: Option<String>
The default policy for all permissions requested by the app. If specified, this overrides the policy-level default_permission_policy which applies to all apps.