Struct google_androidmanagement1::UserFacingMessage [−][src]
pub struct UserFacingMessage {
pub default_message: Option<String>,
pub localized_messages: Option<HashMap<String, String>>,
}Provides a user-facing message with locale info. The maximum message length is 4096 characters.
This type is not used in any activity, and only used as part of another schema.
Fields
default_message: Option<String>
The default message displayed if no localized message is specified or the user's locale doesn't match with any of the localized messages. A default message must be provided if any localized messages are provided.
localized_messages: Option<HashMap<String, String>>
A map containing <locale, message> pairs, where locale is a well-formed BCP 47 language (https://www.w3.org/International/articles/language-tags/) code, such as en-US, es-ES, or fr.